@@ -11,7 +11,6 @@ import {
   FieldMatcherID,
   Field,
   MutableDataFrame,
-  ArrayVector,
 } from '@grafana/data';
 import { Labels } from 'app/types/unified-alerting-dto';
 
@@ -79,13 +78,13 @@ export function toTimeSeriesMulti(data: DataFrame[]): DataFrame[] {
         };
         const builders = new Map<string, frameBuilder>();
         for (let i = 0; i < frame.length; i++) {
-          const time = timeField.values.get(i);
-          const value = field.values.get(i);
+          const time = timeField.values[i];
+          const value = field.values[i];
           if (value === undefined || time == null) {
             continue; // skip values left over from join
           }
 
-          const key = labelFields.map((f) => f.values.get(i)).join('/');
+          const key = labelFields.map((f) => f.values[i]).join('/');
           let builder = builders.get(key);
           if (!builder) {
             builder = {
@@ -95,7 +94,7 @@ export function toTimeSeriesMulti(data: DataFrame[]): DataFrame[] {
               labels: {},
             };
             for (const label of labelFields) {
-              builder.labels[label.name] = label.values.get(i);
+              builder.labels[label.name] = label.values[i];
             }
             builders.set(key, builder);
           }
@@ -115,11 +114,11 @@ export function toTimeSeriesMulti(data: DataFrame[]): DataFrame[] {
             fields: [
               {
                 ...timeField,
-                values: new ArrayVector(b.time),
+                values: b.time,
               },
               {
                 ...field,
-                values: new ArrayVector(b.value),
+                values: b.value,
                 labels: b.labels,
               },
             ],
@@ -219,7 +218,7 @@ export function toTimeSeriesLong(data: DataFrame[]): DataFrame[] {
     const uniqueFactorNamesWithWideIndices: string[] = [];
 
     for (let wideRowIndex = 0; wideRowIndex < frame.length; wideRowIndex++) {
-      sortedTimeRowIndices.push({ time: timeField.values.get(wideRowIndex), wideRowIndex: wideRowIndex });
+      sortedTimeRowIndices.push({ time: timeField.values[wideRowIndex], wideRowIndex: wideRowIndex });
     }
 
     for (const labelKeys in labelKeyToWideIndices) {
@@ -258,7 +257,7 @@ export function toTimeSeriesLong(data: DataFrame[]): DataFrame[] {
         const rowValues: Record<string, any> = {};
 
         for (const name of uniqueFactorNamesWithWideIndices) {
-          rowValues[name] = frame.fields[uniqueFactorNamesToWideIndex[name]].values.get(wideRowIndex);
+          rowValues[name] = frame.fields[uniqueFactorNamesToWideIndex[name]].values[wideRowIndex];
         }
 
         let index = 0;
@@ -272,7 +271,7 @@ export function toTimeSeriesLong(data: DataFrame[]): DataFrame[] {
             }
           }
 
-          rowValues[wideField.name] = wideField.values.get(wideRowIndex);
+          rowValues[wideField.name] = wideField.values[wideRowIndex];
         }
 
         rowValues[timeField.name] = time;
