@@ -1,8 +1,7 @@
-import { render, screen } from '@testing-library/react';
-import React from 'react';
+import { render, screen, waitFor } from '@testing-library/react';
 
+import { createLokiDatasource } from '../../__mocks__/datasource';
 import { LokiDatasource } from '../../datasource';
-import { createLokiDatasource } from '../../mocks';
 import { LokiQuery } from '../../types';
 
 import { LabelBrowserModal, Props } from './LabelBrowserModal';
@@ -33,14 +32,15 @@ describe('LabelBrowserModal', () => {
   it('renders the label browser modal when open', async () => {
     render(<LabelBrowserModal {...props} />);
 
-    expect(await screen.findByText(/Loading/)).not.toBeInTheDocument();
-
+    await waitFor(() => {
+      expect(screen.queryByText(/Loading/)).not.toBeInTheDocument();
+    });
     expect(screen.getByRole('heading', { name: /label browser/i })).toBeInTheDocument();
   });
 
   it("doesn't render the label browser modal when closed", async () => {
     render(<LabelBrowserModal {...props} isOpen={false} />);
 
-    expect(screen.queryByRole('heading', { name: /label browser/i })).toBeNull();
+    expect(screen.queryByRole('heading', { name: /label browser/i })).not.toBeInTheDocument();
   });
 });
